==> sumus-6.3.1-sources.jar: io/intino/sumus/graph/Palette.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Ticket;
import io.intino.sumus.graph.Palette;
import io.intino.sumus.graph.DataRetriever;


public class Palette extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.sumus.graph.functions.ColorOf colorOf;
	protected java.util.List<io.intino.sumus.graph.Palette.Color> colorList = new java.util.ArrayList<>();

	public Palette(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public String colorOf(Ticket ticket, DataRetriever dataRetriever, Palette.Color.Type type) {
		return colorOf.colorOf(ticket, dataRetriever, type);
	}

	public Palette colorOf(io.intino.sumus.graph.functions.ColorOf value) {
		this.colorOf = io.intino.tara.magritte.loaders.FunctionLoader.load(colorOf, this, io.intino.sumus.graph.functions.ColorOf.class);
		return (Palette) this;
	}

	public java.util.List<io.intino.sumus.graph.Palette.Color> colorList() {
		return java.util.Collections.unmodifiableList(colorList);
	}

	public io.intino.sumus.graph.Palette.Color color(int index) {
		return colorList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Palette.Color> colorList(java.util.function.Predicate<io.intino.sumus.graph.Palette.Color> predicate) {
		return colorList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(colorList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("colorOf", this.colorOf != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.colorOf)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Palette$Color")) this.colorList.add(node.as(io.intino.sumus.graph.Palette.Color.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Palette$Color")) this.colorList.remove(node.as(io.intino.sumus.graph.Palette.Color.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("colorOf")) this.colorOf = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.ColorOf.class).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("colorOf")) this.colorOf = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.ColorOf.class);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Palette.Color color(io.intino.sumus.graph.Ticket ticket, io.intino.sumus.graph.DataRetriever dataRetriever, java.lang.String colorCode) {
		    io.intino.sumus.graph.Palette.Color newElement = core$().graph().concept(io.intino.sumus.graph.Palette.Color.class).createNode(name, core$()).as(io.intino.sumus.graph.Palette.Color.class);
			newElement.core$().set(newElement, "ticket", java.util.Collections.singletonList(ticket));
			newElement.core$().set(newElement, "dataRetriever", java.util.Collections.singletonList(dataRetriever));
			newElement.core$().set(newElement, "colorCode", java.util.Collections.singletonList(colorCode));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void color(java.util.function.Predicate<io.intino.sumus.graph.Palette.Color> filter) {
			new java.util.ArrayList<>(colorList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Color extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Ticket ticket;
		protected io.intino.sumus.graph.DataRetriever dataRetriever;
		protected Type type;

		public enum Type {
			Main, Max, Min, Drill1, Drill2, Drill3, Drill4, Drill5;
		}
		protected io.intino.tara.magritte.Expression<java.lang.String> id;
		protected java.lang.String colorCode;

		public Color(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Ticket ticket() {
			return ticket;
		}

		public io.intino.sumus.graph.DataRetriever dataRetriever() {
			return dataRetriever;
		}

		public Type type() {
			return type;
		}

		public java.lang.String id() {
			return id.value();
		}

		public java.lang.String colorCode() {
			return colorCode;
		}

		public Color ticket(io.intino.sumus.graph.Ticket value) {
			this.ticket = value;
			return (Color) this;
		}

		public Color dataRetriever(io.intino.sumus.graph.DataRetriever value) {
			this.dataRetriever = value;
			return (Color) this;
		}

		public Color type(io.intino.sumus.graph.Palette.Color.Type value) {
			this.type = value;
			return (Color) this;
		}

		public Color id(io.intino.tara.magritte.Expression<java.lang.String> value) {
			this.id = io.intino.tara.magritte.loaders.FunctionLoader.load(value, this, io.intino.tara.magritte.Expression.class);
			return (Color) this;
		}

		public Color colorCode(java.lang.String value) {
			this.colorCode = value;
			return (Color) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("ticket", this.ticket != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.ticket)) : java.util.Collections.emptyList());
			map.put("dataRetriever", this.dataRetriever != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.dataRetriever)) : java.util.Collections.emptyList());
			map.put("type", new java.util.ArrayList(java.util.Collections.singletonList(this.type)));
			map.put("id", new java.util.ArrayList(java.util.Collections.singletonList(this.id)));
			map.put("colorCode", new java.util.ArrayList(java.util.Collections.singletonList(this.colorCode)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("ticket")) this.ticket = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Ticket.class, this).get(0);
			else if (name.equalsIgnoreCase("dataRetriever")) this.dataRetriever = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.DataRetriever.class, this).get(0);
			else if (name.equalsIgnoreCase("type")) this.type = io.intino.tara.magritte.loaders.WordLoader.load(values, Type.class, this).get(0);
			else if (name.equalsIgnoreCase("id")) this.id = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.tara.magritte.Expression.class).get(0);
			else if (name.equalsIgnoreCase("colorCode")) this.colorCode = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("ticket")) this.ticket = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Ticket.class) : null;
			else if (name.equalsIgnoreCase("dataRetriever")) this.dataRetriever = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.DataRetriever.class) : null;
			else if (name.equalsIgnoreCase("type")) this.type = (Type) values.get(0);
			else if (name.equalsIgnoreCase("id")) this.id = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.tara.magritte.Expression.class);
			else if (name.equalsIgnoreCase("colorCode")) this.colorCode = (java.lang.String) values.get(0);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/Palette.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Palette;
import io.intino.sumus.graph.DataRetriever;


public class Palette extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
	protected io.intino.sumus.graph.functions.ColorOf colorOf;
	protected java.util.List<io.intino.sumus.graph.Palette.Color> colorList = new java.util.ArrayList<>();

	public Palette(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public String colorOf(DataRetriever dataRetriever, Palette.Color.Type type) {
		return colorOf.colorOf(dataRetriever, type);
	}

	public Palette colorOf(io.intino.sumus.graph.functions.ColorOf value) {
		this.colorOf = io.intino.tara.magritte.loaders.FunctionLoader.load(colorOf, this, io.intino.sumus.graph.functions.ColorOf.class);
		return (Palette) this;
	}

	public java.util.List<io.intino.sumus.graph.Palette.Color> colorList() {
		return java.util.Collections.unmodifiableList(colorList);
	}

	public io.intino.sumus.graph.Palette.Color color(int index) {
		return colorList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Palette.Color> colorList(java.util.function.Predicate<io.intino.sumus.graph.Palette.Color> predicate) {
		return colorList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(colorList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		map.put("colorOf", this.colorOf != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.colorOf)) : java.util.Collections.emptyList());
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Palette$Color")) this.colorList.add(node.as(io.intino.sumus.graph.Palette.Color.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Palette$Color")) this.colorList.remove(node.as(io.intino.sumus.graph.Palette.Color.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("colorOf")) this.colorOf = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.ColorOf.class).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("colorOf")) this.colorOf = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.ColorOf.class);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.sumus.graph.Palette.Color color(io.intino.sumus.graph.DataRetriever dataRetriever, java.lang.String colorCode) {
		    io.intino.sumus.graph.Palette.Color newElement = core$().graph().concept(io.intino.sumus.graph.Palette.Color.class).createNode(name, core$()).as(io.intino.sumus.graph.Palette.Color.class);
			newElement.core$().set(newElement, "dataRetriever", java.util.Collections.singletonList(dataRetriever));
			newElement.core$().set(newElement, "colorCode", java.util.Collections.singletonList(colorCode));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void color(java.util.function.Predicate<io.intino.sumus.graph.Palette.Color> filter) {
			new java.util.ArrayList<>(colorList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Color extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.DataRetriever dataRetriever;
		protected Type type;

		public enum Type {
			Main, Max, Min, Drill1, Drill2, Drill3, Drill4, Drill5;
		}
		protected io.intino.tara.magritte.Expression<java.lang.String> id;
		protected java.lang.String colorCode;

		public Color(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.DataRetriever dataRetriever() {
			return dataRetriever;
		}

		public Type type() {
			return type;
		}

		public java.lang.String id() {
			return id.value();
		}

		public java.lang.String colorCode() {
			return colorCode;
		}

		public Color dataRetriever(io.intino.sumus.graph.DataRetriever value) {
			this.dataRetriever = value;
			return (Color) this;
		}

		public Color type(io.intino.sumus.graph.Palette.Color.Type value) {
			this.type = value;
			return (Color) this;
		}

		public Color id(io.intino.tara.magritte.Expression<java.lang.String> value) {
			this.id = io.intino.tara.magritte.loaders.FunctionLoader.load(value, this, io.intino.tara.magritte.Expression.class);
			return (Color) this;
		}

		public Color colorCode(java.lang.String value) {
			this.colorCode = value;
			return (Color) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("dataRetriever", this.dataRetriever != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.dataRetriever)) : java.util.Collections.emptyList());
			map.put("type", new java.util.ArrayList(java.util.Collections.singletonList(this.type)));
			map.put("id", new java.util.ArrayList(java.util.Collections.singletonList(this.id)));
			map.put("colorCode", new java.util.ArrayList(java.util.Collections.singletonList(this.colorCode)));
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("dataRetriever")) this.dataRetriever = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.DataRetriever.class, this).get(0);
			else if (name.equalsIgnoreCase("type")) this.type = io.intino.tara.magritte.loaders.WordLoader.load(values, Type.class, this).get(0);
			else if (name.equalsIgnoreCase("id")) this.id = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.tara.magritte.Expression.class).get(0);
			else if (name.equalsIgnoreCase("colorCode")) this.colorCode = io.intino.tara.magritte.loaders.StringLoader.load(values, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("dataRetriever")) this.dataRetriever = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.DataRetriever.class) : null;
			else if (name.equalsIgnoreCase("type")) this.type = (Type) values.get(0);
			else if (name.equalsIgnoreCase("id")) this.id = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.tara.magritte.Expression.class);
			else if (name.equalsIgnoreCase("colorCode")) this.colorCode = (java.lang.String) values.get(0);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
